@@ -1,5 +1,5 @@
 from django.conf import settings
-from django.db import models, transaction
+from django.db import connections, models, router, transaction
 from django.utils.translation import gettext_lazy as _
 from psycopg2 import sql
 
@@ -156,7 +156,7 @@ class TriggerLogAbstract(models.Model):
             model_cls = get_connected_model_for_table_name(table_name)
             exclude_cols = cls._fieldnames_to_colnames(model_cls, exclude_fields)
 
-        raw_query = sql.SQL(
+        composed_query = sql.SQL(
             """
             SELECT {schema}.hc_capture_insert_from_row(
               hstore({schema}.{table_name}.*),
@@ -174,7 +174,8 @@ class TriggerLogAbstract(models.Model):
             ),
         )
         params = {"record_id": record_id, "table_name": table_name}
-        result_qs = TriggerLog.objects.raw(raw_query, params)
+        raw_sql = cls._compile_sql(TriggerLog, composed_query)
+        result_qs = TriggerLog.objects.raw(raw_sql, params)
         if not result_qs:
             raise TriggerLog.DoesNotExist(
                 "TriggerLog was not created after re-capturing INSERT"
@@ -214,7 +215,7 @@ class TriggerLogAbstract(models.Model):
             model_cls = get_connected_model_for_table_name(table_name)
             include_cols.update(cls._fieldnames_to_colnames(model_cls, update_fields))
 
-        raw_query = sql.SQL(
+        composed_query = sql.SQL(
             """
             SELECT {schema}.hc_capture_update_from_row(
               hstore({schema}.{table_name}.*),
@@ -233,7 +234,8 @@ class TriggerLogAbstract(models.Model):
             "table_name": table_name,
             "include_cols": list(include_cols),
         }
-        result_qs = TriggerLog.objects.raw(raw_query, params)
+        raw_sql = cls._compile_sql(TriggerLog, composed_query)
+        result_qs = TriggerLog.objects.raw(raw_sql, params)
         if not result_qs:
             raise TriggerLog.DoesNotExist(
                 "TriggerLog was not created after re-capturing UPDATE"
@@ -320,6 +322,12 @@ class TriggerLogAbstract(models.Model):
         fields = map(get_field, fieldnames)
         return {f.column for f in fields}
 
+    @staticmethod
+    def _compile_sql(model_cls, composed_query):
+        db_name = router.db_for_read(model_cls)
+        with connections[db_name].cursor().cursor as cursor:
+            return composed_query.as_string(cursor)
+
 
 class TriggerLog(TriggerLogAbstract):
     """
